@@ -97,6 +97,20 @@ will be placed under the key 'I<Package::Name>' in xsdocparse's data
 structure.  Everything from this line to the next C<=cut> is included as a
 description POD.
 
+=item =for object Package::Name (Other::Package::Name)
+
+Generate POD in I<Package::Name> but for the package I<Other::Package::Name>.
+This is useful if you want POD to appear in a different namespace but still
+want the automatically generated hierarchy, signal and property listing,
+etc. from the original namespace.  For example:
+
+  =for object Gnome2::PanelApplet::main (Gnome2::PanelApplet)
+  =cut
+
+This will create Gnome2/PanelApplet/main.pod containing the automatically
+generated documentation for Gnome2::PanelApplet (hierarchy, signals, etc.) plus
+the method listing from the current XS file.
+
 =item =for enum Package::Name
 
 =item =for flags Package::Name
@@ -379,6 +393,8 @@ our %basic_types = (
 	subroutine => 'subroutine',
 	integer    => 'integer',
 	string     => 'string',
+	package    => 'package',
+	list       => 'list',
 
 	# other C names which may sneak through
 	bool     => 'boolean', # C++ keyword, but provided by the perl api
@@ -568,13 +584,13 @@ sub podify_deprecated_by
 	$str .= "You should use "
 	      . join (', ',
 	              map {
-		      	if (/^\s*L</) {
-					$_;
-				}
-				else {
-					"L<$_>";
-				}
-				  } @deprecated_by)
+			if (/^\s*L</) {
+				$_;
+			}
+			else {
+				"L<$_>";
+			}
+		      } @deprecated_by)
 	      . " instead of $package.\n";
 
 	return $str;
@@ -823,8 +839,7 @@ I<$packagename>.
 sub podify_methods
 {
 	my $package = shift;
-	return undef unless $data->{$package};
-	my $xsubs = $data->{$package}{xsubs};
+	my $xsubs = shift;
 	return undef unless $xsubs && @$xsubs;
 	# we will be re-using $package from here on out.
 
@@ -1025,6 +1040,9 @@ sub convert_type {
 	              (\s*\*)?				# maybe a star
 	              \s*$/x;				# trailing space
 	my $ctype   = $1 || '!!';
+	if ($ctype eq '!!') {
+		warn "Glib::GenPod: Unable to parse type `$typestr´";
+	}
 
 	# variant type
 	$ctype =~ s/(?:_(ornull|own|copy|own_ornull|noinc))$//;
@@ -1186,8 +1204,25 @@ sub xsub_to_pod {
 	$str .= "May croak with a L<Glib::Error> in \$@ on failure.\n\n"
 		if ($xsub->{gerror});
 
-    $str .= "This method is deprecated and should not be used in newly written code.\n\n"
-        if ($xsub->{deprecated});
+	$str .= "This method is deprecated and should not be used in newly written code.\n\n"
+		if ($xsub->{deprecated});
+
+
+	# When there are multiple version guards of the same type, we only want
+	# the innermost.
+	my %version_conditions;
+	my %prefix_to_name = (
+		GTK => 'gtk+',
+	);
+	foreach (@{ $xsub->{preprocessor_conditionals} }) {
+		if (m/^\s*(\w+)_CHECK_VERSION\s*\((\d+),\s*(\d+)/) {
+			my $lib_name = $prefix_to_name{$1} || lc $1;
+			$version_conditions{$lib_name} = "$2.$3";
+		}
+	}
+	foreach my $lib_name (keys %version_conditions) {
+		$str .= "Since: $lib_name $version_conditions{$lib_name}\n\n";
+	}
 
 	$str .= "=back\n\n";
 
